Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Executable is the name shown by Cobra when we use its // cli command Executable = "kubeletmein" // GitVersion is overridden by Makefile with git information GitVersion = "NoGitVersion" )
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Provider string
SkipBootstrap bool
BootstrapConfig string
CaCertPath string
KubeletKeyPath string
KubeletCertPath string
KubeletToken string
KubeConfig string
CertDir string
NodeName string
KubeAPIServer string
MetadataFile string
Region string
}
Config holds configuration values for the various operations
Click to show internal directories.
Click to hide internal directories.